package org.dive4elements.river.artifacts.model.minfo;

import org.apache.log4j.Logger;
import org.dive4elements.artifactdatabase.state.Facet;
import org.dive4elements.artifacts.Artifact;
import org.dive4elements.artifacts.CallContext;
import org.dive4elements.river.artifacts.D4EArtifact;
import org.dive4elements.river.artifacts.model.CalculationResult;
import org.dive4elements.river.artifacts.model.DataFacet;
import org.dive4elements.river.artifacts.model.FacetTypes;
import org.dive4elements.river.artifacts.states.DefaultState.ComputeType;


public class BedDiffSoundingWidthFacet
extends DataFacet
implements FacetTypes
{
    private static Logger log = Logger.getLogger(BedDiffSoundingWidthFacet.class);

    public BedDiffSoundingWidthFacet() {
    }

    public BedDiffSoundingWidthFacet(int idx, String name, String description,
        ComputeType type, String stateId, String hash) {
        super(idx, name, description, type, hash, stateId);
        this.metaData.put("X", "chart.longitudinal.section.xaxis.label");
        this.metaData.put("Y", "chart.bedheight_middle.sounding.yaxis.label");
    }

    public Object getData(Artifact artifact, CallContext context) {
        log.debug("Get data for bed density at index: " + index);

        D4EArtifact flys = (D4EArtifact) artifact;

        CalculationResult res = (CalculationResult) flys.compute(context, hash,
            stateId, type, false);

        BedDiffYearResult[] resultData =
            (BedDiffYearResult[]) res.getData(); // TODO CAST TO SPECIFIC CLASS

        if (resultData != null && resultData.length > index) {
            BedDiffYearResult data = resultData[index];
            //TODO this only returns sounding width for minuend.
            return data.getSoundingWidth1Data();
        }
        return null;
    }

    /** Copy deeply. */
    @Override
    public Facet deepCopy() {
        BedDiffSoundingWidthFacet copy = new BedDiffSoundingWidthFacet();
        copy.set(this);
        copy.type = type;
        copy.hash = hash;
        copy.stateId = stateId;
        return copy;
    }
}
